@@ -15,9 +15,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -34,6 +33,7 @@ from ._hasidof import HasIdOf
 from ._hasnote import HasNote
 from ._hasnotematchingsubstringof import HasNoteMatchingSubstringOf
 from ._hasnoteregexp import HasNoteRegexp
+from ._hasnotetype import HasNoteType
 from ._hasreferencecountof import HasReferenceCountOf
 from ._hassource import HasSource
 from ._hassourceidof import HasSourceIdOf
@@ -56,6 +56,7 @@ editor_rule_list = [
     HasIdOf,
     HasNote,
     HasNoteRegexp,
+    HasNoteType,
     HasReferenceCountOf,
     HasSource,
     HasSourceIdOf,
