@@ -14,40 +14,38 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
 Filter rule to match family with a particular citation.
 """
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hascitationbase import HasCitationBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # HasEvent
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasCitation(HasCitationBase):
     """Rule that checks for a family with a particular value"""
 
-    labels      = [ _('Volume/Page:'), 
-                    _('Date:'), 
-                    _('Confidence level:')]
-    name        =  _('Families with the <citation>')
-    description = _("Matches families with a citation of a particular "
-                    "value")
+    labels = [_("Volume/Page:"), _("Date:"), _("Confidence level:")]
+    name = _("Families with the <citation>")
+    description = _("Matches families with a citation of a particular " "value")
