@@ -13,9 +13,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 # -------------------------------------------------------------------------
@@ -36,6 +35,15 @@ from .. import Rule
 from ._matchesfilter import MatchesFilter
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Person
+from ....db import Database
+
+
 # -------------------------------------------------------------------------
 #
 # IsSpouseOfFilterMatch
@@ -50,23 +58,23 @@ class IsSpouseOfFilterMatch(Rule):
     description = _("Matches people married to anybody matching a filter")
     category = _("Family filters")
 
-    def prepare(self, db, user):
+    def prepare(self, db: Database, user):
         self.filt = MatchesFilter(self.list)
         self.filt.requestprepare(db, user)
 
-    def apply(self, db, person):
-        for family_handle in person.get_family_handle_list():
+    def apply_to_one(self, db: Database, person: Person) -> bool:
+        for family_handle in person.family_list:
             family = db.get_family_from_handle(family_handle)
             if family:
                 for spouse_id in [
-                    family.get_father_handle(),
-                    family.get_mother_handle(),
+                    family.father_handle,
+                    family.mother_handle,
                 ]:
                     if not spouse_id:
                         continue
                     if spouse_id == person.handle:
                         continue
-                    if self.filt.apply(db, db.get_person_from_handle(spouse_id)):
+                    if self.filt.apply_to_one(db, db.get_person_from_handle(spouse_id)):
                         return True
         return False
 
