@@ -13,31 +13,32 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hasnoteregexbase import HasNoteRegexBase
 
-#-------------------------------------------------------------------------
-# "Repos having notes that contain a substring"
-#-------------------------------------------------------------------------
-class HasNoteRegexp(HasNoteRegexBase):
 
-    name        = _('Repositories having notes containing <text>')
-    description = _("Matches repositories whose notes contain text "
-                    "matching a regular expression")
+# -------------------------------------------------------------------------
+# "Repos having notes that contain a substring"
+# -------------------------------------------------------------------------
+class HasNoteRegexp(HasNoteRegexBase):
+    name = _("Repositories having notes containing <text>")
+    description = _(
+        "Matches repositories whose notes contain text " "matching a regular expression"
+    )
