@@ -15,32 +15,33 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 # gen.filters.rules/Source/_HasGallery.py
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from .._hasgallerybase import HasGalleryBase
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 # "Sources who have media object reference"
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasGallery(HasGalleryBase):
     """Rule that checks for source who has media object reference"""
 
-    name = _('Sources with <count> media')
+    name = _("Sources with <count> media")
     description = _("Matches sources with a certain number of items in the gallery")
