@@ -13,27 +13,26 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
 Provide calendar to sdn (serial date number) conversion.
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import math
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Constants
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 _GRG_SDN_OFFSET = 32045
 _GRG_DAYS_PER_5_MONTHS = 153
 _GRG_DAYS_PER_4_YEARS = 1461
@@ -60,14 +59,48 @@ _HBR_WEDNESDAY = 3
 _HBR_FRIDAY = 5
 
 _HBR_MONTHS_PER_YEAR = [
-    12, 12, 13, 12, 12, 13, 12, 13, 12, 12,
-    13, 12, 12, 13, 12, 12, 13, 12, 13
-    ]
+    12,
+    12,
+    13,
+    12,
+    12,
+    13,
+    12,
+    13,
+    12,
+    12,
+    13,
+    12,
+    12,
+    13,
+    12,
+    12,
+    13,
+    12,
+    13,
+]
 
 _HBR_YEAR_OFFSET = [
-    0, 12, 24, 37, 49, 61, 74, 86, 99, 111, 123,
-    136, 148, 160, 173, 185, 197, 210, 222
-    ]
+    0,
+    12,
+    24,
+    37,
+    49,
+    61,
+    74,
+    86,
+    99,
+    111,
+    123,
+    136,
+    148,
+    160,
+    173,
+    185,
+    197,
+    210,
+    222,
+]
 
 _FR_SDN_OFFSET = 2375474
 _FR_DAYS_PER_4_YEARS = 1461
@@ -75,19 +108,23 @@ _FR_DAYS_PER_MONTH = 30
 _PRS_EPOCH = 1948320.5
 _ISM_EPOCH = 1948439.5
 
-def _tishri1(metonic_year, molad_day, molad_halakim):
 
+def _tishri1(metonic_year, molad_day, molad_halakim):
     tishri1 = molad_day
     dow = tishri1 % 7
     leap_year = metonic_year in [2, 5, 7, 10, 13, 16, 18]
     last_was_leap_year = metonic_year in [3, 6, 8, 11, 14, 17, 0]
 
     # Apply rules 2, 3 and 4.
-    if ((molad_halakim >= _HBR_NOON) or
-            ((not leap_year) and dow == _HBR_TUESDAY and
-             molad_halakim >= _HBR_AM3_11_20) or
-            (last_was_leap_year and dow == _HBR_MONDAY
-             and molad_halakim >= _HBR_AM9_32_43)):
+    if (
+        (molad_halakim >= _HBR_NOON)
+        or ((not leap_year) and dow == _HBR_TUESDAY and molad_halakim >= _HBR_AM3_11_20)
+        or (
+            last_was_leap_year
+            and dow == _HBR_MONDAY
+            and molad_halakim >= _HBR_AM9_32_43
+        )
+    ):
         tishri1 += 1
         dow += 1
         if dow == 7:
@@ -95,11 +132,12 @@ def _tishri1(metonic_year, molad_day, molad_halakim):
 
     # Apply rule 1 after the others because it can cause an additional
     # delay of one day
-    if dow == _HBR_WEDNESDAY or dow == _HBR_FRIDAY or dow == _HBR_SUNDAY:
+    if dow in [_HBR_WEDNESDAY, _HBR_FRIDAY, _HBR_SUNDAY]:
         tishri1 += 1
 
     return tishri1
 
+
 def _tishri_molad(input_day):
     """
     Estimate the metonic cycle number.
@@ -132,13 +170,15 @@ def _tishri_molad(input_day):
         if molad_day > input_day - 74:
             break
 
-        molad_halakim += (_HBR_HALAKIM_PER_LUNAR_CYCLE
-                          * _HBR_MONTHS_PER_YEAR[metonic_year])
+        molad_halakim += (
+            _HBR_HALAKIM_PER_LUNAR_CYCLE * _HBR_MONTHS_PER_YEAR[metonic_year]
+        )
         molad_day += molad_halakim // _HBR_HALAKIM_PER_DAY
         molad_halakim = molad_halakim % _HBR_HALAKIM_PER_DAY
 
     return (metonic_cycle, metonic_year, molad_day, molad_halakim)
 
+
 def _molad_of_metonic_cycle(metonic_cycle):
     """
     Start with the time of the first molad after creation.
@@ -152,7 +192,7 @@ def _molad_of_metonic_cycle(metonic_cycle):
 
     r1 = r1 + (metonic_cycle * (_HBR_HALAKIM_PER_METONIC_CYCLE & 0xFFFF))
     r2 = r1 >> 16
-    r2 = r2 + (metonic_cycle * ((_HBR_HALAKIM_PER_METONIC_CYCLE >> 16)&0xFFFF))
+    r2 = r2 + (metonic_cycle * ((_HBR_HALAKIM_PER_METONIC_CYCLE >> 16) & 0xFFFF))
 
     # Calculate r2r1 / HALAKIM_PER_DAY.  The remainder will be in r1, the
     # upper 16 bits of the quotient will be in d2 and the lower 16 bits
@@ -169,6 +209,7 @@ def _molad_of_metonic_cycle(metonic_cycle):
 
     return (molad_day, molad_halakim)
 
+
 def _start_of_year(year):
     """
     Calculate the start of the year.
@@ -177,8 +218,9 @@ def _start_of_year(year):
     metonic_year = (year - 1) % 19
     (molad_day, molad_halakim) = _molad_of_metonic_cycle(metonic_cycle)
 
-    molad_halakim = molad_halakim + (_HBR_HALAKIM_PER_LUNAR_CYCLE
-                                     * _HBR_YEAR_OFFSET[metonic_year])
+    molad_halakim = molad_halakim + (
+        _HBR_HALAKIM_PER_LUNAR_CYCLE * _HBR_YEAR_OFFSET[metonic_year]
+    )
     molad_day = molad_day + (molad_halakim // _HBR_HALAKIM_PER_DAY)
     molad_halakim = molad_halakim % _HBR_HALAKIM_PER_DAY
 
@@ -186,13 +228,19 @@ def _start_of_year(year):
 
     return (metonic_cycle, metonic_year, molad_day, molad_halakim, ptishri1)
 
+
 def hebrew_sdn(year, month, day):
     """Convert a Jewish calendar date to an SDN number."""
 
-    if month == 1 or month == 2:
+    if month in [1, 2]:
         # It is Tishri or Heshvan - don't need the year length.
-        (metonic_cycle, metonic_year,
-         molad_day, molad_halakim, tishri1) = _start_of_year(year)
+        (
+            metonic_cycle,
+            metonic_year,
+            molad_day,
+            molad_halakim,
+            tishri1,
+        ) = _start_of_year(year)
         if month == 1:
             sdn = tishri1 + day - 1
         else:
@@ -201,28 +249,38 @@ def hebrew_sdn(year, month, day):
         # It is Kislev - must find the year length.
 
         # Find the start of the year.
-        (metonic_cycle, metonic_year,
-         molad_day, molad_halakim, tishri1) = _start_of_year(year)
+        (
+            metonic_cycle,
+            metonic_year,
+            molad_day,
+            molad_halakim,
+            tishri1,
+        ) = _start_of_year(year)
 
         # Find the end of the year.
-        molad_halakim = molad_halakim + (_HBR_HALAKIM_PER_LUNAR_CYCLE
-                                         *_HBR_MONTHS_PER_YEAR[metonic_year])
+        molad_halakim = molad_halakim + (
+            _HBR_HALAKIM_PER_LUNAR_CYCLE * _HBR_MONTHS_PER_YEAR[metonic_year]
+        )
         molad_day = molad_day + (molad_halakim // _HBR_HALAKIM_PER_DAY)
         molad_halakim = molad_halakim % _HBR_HALAKIM_PER_DAY
-        tishri1_after = _tishri1((metonic_year + 1)
-                                 % 19, molad_day, molad_halakim)
+        tishri1_after = _tishri1((metonic_year + 1) % 19, molad_day, molad_halakim)
 
         year_length = tishri1_after - tishri1
 
-        if year_length == 355 or year_length == 385:
+        if year_length in [355, 385]:
             sdn = tishri1 + day + 59
         else:
             sdn = tishri1 + day + 58
-    elif month == 4 or month == 5 or month == 6:
+    elif month in [4, 5, 6]:
         # It is Tevet, Shevat or Adar I - don't need the year length
 
-        (metonic_cycle, metonic_year,
-         molad_day, molad_halakim, tishri1_after) = _start_of_year(year+1)
+        (
+            metonic_cycle,
+            metonic_year,
+            molad_day,
+            molad_halakim,
+            tishri1_after,
+        ) = _start_of_year(year + 1)
 
         if _HBR_MONTHS_PER_YEAR[(year - 1) % 19] == 12:
             length_of_adar_1and2 = 29
@@ -237,8 +295,13 @@ def hebrew_sdn(year, month, day):
             sdn = tishri1_after + day - length_of_adar_1and2 - 178
     else:
         # It is Adar II or later - don't need the year length.
-        (metonic_cycle, metonic_year,
-         molad_day, molad_halakim, tishri1_after) = _start_of_year(year+1)
+        (
+            metonic_cycle,
+            metonic_year,
+            molad_day,
+            molad_halakim,
+            tishri1_after,
+        ) = _start_of_year(year + 1)
 
         if month == 7:
             sdn = tishri1_after + day - 207
@@ -258,6 +321,7 @@ def hebrew_sdn(year, month, day):
             return 0
     return sdn + _HBR_SDN_OFFSET
 
+
 def hebrew_ymd(sdn):
     """Convert an SDN number to a Hebrew calendar date."""
 
@@ -283,8 +347,7 @@ def hebrew_ymd(sdn):
         # We need the length of the year to figure this out, so find
         # Tishri 1 of the next year.
 
-        halakim += (_HBR_HALAKIM_PER_LUNAR_CYCLE
-                    * _HBR_MONTHS_PER_YEAR[metonic_year])
+        halakim += _HBR_HALAKIM_PER_LUNAR_CYCLE * _HBR_MONTHS_PER_YEAR[metonic_year]
         day1 += halakim // _HBR_HALAKIM_PER_DAY
         halakim = halakim % _HBR_HALAKIM_PER_DAY
         tishri1_after = _tishri1((metonic_year + 1) % 19, day1, halakim)
@@ -313,42 +376,42 @@ def hebrew_ymd(sdn):
                 month = 8
                 day = input_day - tishri1 + 178
             return (year, month, day)
-        else:
-            if _HBR_MONTHS_PER_YEAR[(year - 1) % 19] == 13:
-                month = 7
-                day = input_day - tishri1 + 207
-                if day > 0:
-                    return (year, month, day)
-                month -= 1
-                day += 30
-                if day > 0:
-                    return (year, month, day)
-                month -= 1
-                day += 30
-            else:
-                month = 6
-                day = input_day - tishri1 + 207
-                if day > 0:
-                    return (year, month, day)
-                month -= 1
-                day += 30
 
+        if _HBR_MONTHS_PER_YEAR[(year - 1) % 19] == 13:
+            month = 7
+            day = input_day - tishri1 + 207
             if day > 0:
                 return (year, month, day)
             month -= 1
-            day += 29
+            day += 30
             if day > 0:
                 return (year, month, day)
+            month -= 1
+            day += 30
+        else:
+            month = 6
+            day = input_day - tishri1 + 207
+            if day > 0:
+                return (year, month, day)
+            month -= 1
+            day += 30
 
-            # We need the length of the year to figure this out, so find
-            # Tishri 1 of this year
-            tishri1_after = tishri1
-            (metonic_cycle, metonic_year, day1, halakim) = _tishri_molad(day1-365)
-            tishri1 = _tishri1(metonic_year, day1, halakim)
+        if day > 0:
+            return (year, month, day)
+        month -= 1
+        day += 29
+        if day > 0:
+            return (year, month, day)
+
+        # We need the length of the year to figure this out, so find
+        # Tishri 1 of this year
+        tishri1_after = tishri1
+        (metonic_cycle, metonic_year, day1, halakim) = _tishri_molad(day1 - 365)
+        tishri1 = _tishri1(metonic_year, day1, halakim)
 
     year_length = tishri1_after - tishri1
     day = input_day - tishri1 - 29
-    if year_length == 355 or year_length == 385:
+    if year_length in [355, 385]:
         # Heshvan has 30 days
         if day <= 30:
             month = 2
@@ -365,6 +428,7 @@ def hebrew_ymd(sdn):
     # It has to be Kislev
     return (year, 3, day)
 
+
 def julian_sdn(year, month, day):
     """Convert a Julian calendar date to an SDN number."""
 
@@ -380,9 +444,13 @@ def julian_sdn(year, month, day):
         month += 9
         year -= 1
 
-    return (year * _JLN_DAYS_PER_4_YEARS) // 4 \
-           + (month * _JLN_DAYS_PER_5_MONTHS + 2) // 5 \
-           + day - _JLN_SDN_OFFSET
+    return (
+        (year * _JLN_DAYS_PER_4_YEARS) // 4
+        + (month * _JLN_DAYS_PER_5_MONTHS + 2) // 5
+        + day
+        - _JLN_SDN_OFFSET
+    )
+
 
 def julian_ymd(sdn):
     """Convert an SDN number to a Julian date."""
@@ -411,6 +479,7 @@ def julian_ymd(sdn):
 
     return (year, month, day)
 
+
 def gregorian_sdn(year, month, day):
     """Convert a gregorian date to an SDN number."""
     if year < 0:
@@ -425,11 +494,14 @@ def gregorian_sdn(year, month, day):
         month += 9
         year -= 1
 
-    return(((year // 100) * _GRG_DAYS_PER_400_YEARS) // 4
-           + ((year % 100) * _GRG_DAYS_PER_4_YEARS) // 4
-           + (month * _GRG_DAYS_PER_5_MONTHS + 2) // 5
-           + day
-           - _GRG_SDN_OFFSET)
+    return (
+        ((year // 100) * _GRG_DAYS_PER_400_YEARS) // 4
+        + ((year % 100) * _GRG_DAYS_PER_4_YEARS) // 4
+        + (month * _GRG_DAYS_PER_5_MONTHS + 2) // 5
+        + day
+        - _GRG_SDN_OFFSET
+    )
+
 
 def gregorian_ymd(sdn):
     """Convert an SDN number to a gregorian date."""
@@ -461,29 +533,37 @@ def gregorian_ymd(sdn):
         year = year - 1
     return (year, month, day)
 
+
 def _check_republican_period(sdn, restrict_period):
-    # French Republican calendar wasn't in use before 22.9.1792 or after 1.1.1806
+    # French Republican calendar wasn't in use before 22.9.1792 or
+    # after 1.1.1806
     if restrict_period and (sdn < 2375840 or sdn > 2380688):
         raise ValueError("Outside of the French Republican period")
 
+
 def french_sdn(year, month, day, restrict_period=False):
     """Convert a French Republican Calendar date to an SDN number."""
-    sdn = (year*_FR_DAYS_PER_4_YEARS) // 4 + \
-           (month-1)*_FR_DAYS_PER_MONTH + \
-           day + _FR_SDN_OFFSET
+    sdn = (
+        (year * _FR_DAYS_PER_4_YEARS) // 4
+        + (month - 1) * _FR_DAYS_PER_MONTH
+        + day
+        + _FR_SDN_OFFSET
+    )
     _check_republican_period(sdn, restrict_period)
     return sdn
 
+
 def french_ymd(sdn, restrict_period=False):
     """Convert an SDN number to a French Republican Calendar date."""
     _check_republican_period(sdn, restrict_period)
-    temp = (sdn-_FR_SDN_OFFSET)*4 - 1
+    temp = (sdn - _FR_SDN_OFFSET) * 4 - 1
     year = temp // _FR_DAYS_PER_4_YEARS
     day_of_year = (temp % _FR_DAYS_PER_4_YEARS) // 4
     month = (day_of_year // _FR_DAYS_PER_MONTH) + 1
     day = (day_of_year % _FR_DAYS_PER_MONTH) + 1
     return (year, month, day)
 
+
 def persian_sdn(year, month, day):
     """Convert a Persian date to an SDN number."""
     if year >= 0:
@@ -503,25 +583,27 @@ def persian_sdn(year, month, day):
 
     return int(math.ceil(v1 + v2 + v3 + v4 + _PRS_EPOCH - 1))
 
+
 def persian_ymd(sdn):
     """Convert an SDN number to a Persian calendar date."""
-    sdn = math.floor(sdn) + 0.5  #float
+    # The following is commented out and is related to bug 12576
+    # sdn = math.floor(sdn) + 0.5         # float
 
-    depoch = sdn - 2121446       #float
-    cycle = math.floor(depoch / 1029983) #int
-    cyear = depoch % 1029983             #int
+    depoch = sdn - 2121446  # float
+    cycle = math.floor(depoch / 1029983)  # int
+    cyear = depoch % 1029983  # int
     if cyear == 1029982:
         ycycle = 2820
     else:
-        aux1 = cyear // 366 #int
-        aux2 = cyear % 366  #int
-        ycycle = (((2134*aux1)+(2816*aux2)+2815) // 1028522) + aux1 + 1
+        aux1 = cyear // 366  # int
+        aux2 = cyear % 366  # int
+        ycycle = (((2134 * aux1) + (2816 * aux2) + 2815) // 1028522) + aux1 + 1
 
     year = ycycle + (2820 * cycle) + 474
     if year <= 0:
         year = year - 1
 
-    yday = sdn - persian_sdn(year, 1, 1) + 1   #float !
+    yday = sdn - persian_sdn(year, 1, 1) + 1  # float !
     if yday < 186:
         month = math.ceil(yday / 31)
     else:
@@ -529,43 +611,45 @@ def persian_ymd(sdn):
     day = (sdn - persian_sdn(year, month, 1)) + 1
     return (int(year), int(month), int(day))
 
+
 def islamic_sdn(year, month, day):
     """Convert an Islamic date to an SDN number."""
     v1 = math.ceil(29.5 * (month - 1))
     v2 = (year - 1) * 354
-    v3 = math.floor((3 + (11 *year)) // 30)
+    v3 = math.floor((3 + (11 * year)) // 30)
 
     return int(math.ceil((day + v1 + v2 + v3 + _ISM_EPOCH) - 1))
 
+
 def islamic_ymd(sdn):
     """Convert an SDN number to an Islamic calendar date."""
     sdn = math.floor(sdn) + 0.5
-    year = int(math.floor(((30*(sdn-_ISM_EPOCH))+10646) / 10631))
-    month = int(min(12, math.ceil((sdn-(29+islamic_sdn(year, 1, 1))) / 29.5) + 1))
+    year = int(math.floor(((30 * (sdn - _ISM_EPOCH)) + 10646) / 10631))
+    month = int(min(12, math.ceil((sdn - (29 + islamic_sdn(year, 1, 1))) / 29.5) + 1))
     day = int((sdn - islamic_sdn(year, month, 1)) + 1)
     return (year, month, day)
 
+
 def swedish_sdn(year, month, day):
     """Convert a Swedish date to an SDN number."""
     datum = (year, month, day)
     # Swedish Calendar
     if (1700, 3, 1) <= datum <= (1712, 2, 30):
-        return julian_sdn(year, month, day) -1
+        return julian_sdn(year, month, day) - 1
     # Gregorian Calendar (1753-03-01)
-    elif (1753, 3, 1) <= datum:
+    if (1753, 3, 1) <= datum:
         return gregorian_sdn(year, month, day)
-    else:
-        return julian_sdn(year, month, day)
+    return julian_sdn(year, month, day)
+
 
 def swedish_ymd(sdn):
     """Convert an SDN number to a Swedish calendar date."""
     if sdn == 2346425:
         return (1712, 2, 30)
     # Swedish Calendar
-    elif 2342042 <= sdn < 2346425:
-        return julian_ymd(sdn+1)
+    if 2342042 <= sdn < 2346425:
+        return julian_ymd(sdn + 1)
     # Gregorian Calendar (1753-03-01)
-    elif sdn >= 2361390:
+    if sdn >= 2361390:
         return gregorian_ymd(sdn)
-    else:
-        return julian_ymd(sdn)
+    return julian_ymd(sdn)
