@@ -15,9 +15,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -29,17 +28,17 @@ Surname class for Gramps.
 # Gramps modules
 #
 # -------------------------------------------------------------------------
-from .secondaryobj import SecondaryObject
-from .nameorigintype import NameOriginType
-from .const import IDENTICAL, EQUAL, DIFFERENT
 from ..const import GRAMPS_LOCALE as glocale
+from .const import DIFFERENT, EQUAL, IDENTICAL
+from .nameorigintype import NameOriginType
+from .secondaryobj import SecondaryObject
 
 _ = glocale.translation.gettext
 
 
 # -------------------------------------------------------------------------
 #
-# Personal Name
+# Surname
 #
 # -------------------------------------------------------------------------
 class Surname(SecondaryObject):
@@ -69,6 +68,25 @@ class Surname(SecondaryObject):
         if data:
             self.unserialize(data)
 
+    def get_object_state(self):
+        """
+        Get the current object state as a dictionary.
+        """
+        attr_dict = dict(
+            (key, value)
+            for key, value in self.__dict__.items()
+            if not key.startswith("_")
+        )
+        attr_dict["_class"] = self.__class__.__name__
+        return attr_dict
+
+    def set_object_state(self, attr_dict):
+        """
+        Set the current object state using information provided in the given
+        dictionary.
+        """
+        self.__dict__.update(attr_dict)
+
     def serialize(self):
         """
         Convert the object to a serialized tuple of data.
@@ -112,7 +130,13 @@ class Surname(SecondaryObject):
         """
         Convert a serialized tuple of data to an object.
         """
-        (self.surname, self.prefix, self.primary, origin_type, self.connector) = data
+        (
+            self.surname,
+            self.prefix,
+            self.primary,
+            origin_type,
+            self.connector,
+        ) = data
         self.origintype = NameOriginType(origin_type)
         return self
 
@@ -141,11 +165,9 @@ class Surname(SecondaryObject):
             or self.primary != other.primary
         ):
             return DIFFERENT
-        else:
-            if self.is_equal(other):
-                return IDENTICAL
-            else:
-                return EQUAL
+        if self.is_equal(other):
+            return IDENTICAL
+        return EQUAL
 
     def merge(self, acquisition):
         """
@@ -156,7 +178,6 @@ class Surname(SecondaryObject):
         :param acquisition: The surname to merge with the present surname.
         :type acquisition: Surname
         """
-        pass
 
     def get_surname(self):
         """
