@@ -10,46 +10,46 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
 Configuration based utilities
 """
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ..lib import Researcher
 from ..config import config
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # Configuration based utilities
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def get_researcher():
     """
     Return a new database owner with the default values from the config file.
     """
-    name  = config.get('researcher.researcher-name')
-    address  = config.get('researcher.researcher-addr')
-    locality  = config.get('researcher.researcher-locality')
-    city  = config.get('researcher.researcher-city')
-    state  = config.get('researcher.researcher-state')
-    country = config.get('researcher.researcher-country')
-    post_code  = config.get('researcher.researcher-postal')
-    phone = config.get('researcher.researcher-phone')
-    email  = config.get('researcher.researcher-email')
+    name = config.get("researcher.researcher-name")
+    address = config.get("researcher.researcher-addr")
+    locality = config.get("researcher.researcher-locality")
+    city = config.get("researcher.researcher-city")
+    state = config.get("researcher.researcher-state")
+    country = config.get("researcher.researcher-country")
+    post_code = config.get("researcher.researcher-postal")
+    phone = config.get("researcher.researcher-phone")
+    email = config.get("researcher.researcher-email")
 
     owner = Researcher()
     owner.set_name(name)
