@@ -15,71 +15,72 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """Format of commonly used expressions, making use of a cache to not
 recompute
 """
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from html import escape
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+from gramps.gen.utils.symbols import Symbols
 from ..lib import EventType
 from ..datehandler import get_date
 from ..display.name import displayer as name_displayer
 from ..display.place import displayer as place_displayer
-from .db import (get_birth_or_fallback, get_death_or_fallback,
-                 get_marriage_or_fallback)
-from gramps.gen.utils.symbols import Symbols
+from .db import get_birth_or_fallback, get_death_or_fallback, get_marriage_or_fallback
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # FormattingHelper class
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class FormattingHelper:
     """Format of commonly used expressions, making use of a cache to not
     recompute
     """
+
     def __init__(self, dbstate, uistate=None):
         self.dbstate = dbstate
         self.uistate = uistate
         self._text_cache = {}
         self._markup_cache = {}
-        self.symbols = Symbols()
         self.reload_symbols()
 
     def reload_symbols(self):
+        self.symbols = Symbols()
         self.clear_cache()
         if self.uistate and self.uistate.symbols:
             death_idx = self.uistate.death_symbol
-            self.male = self.symbols.get_symbol_for_string(self.symbols.SYMBOL_MALE)
-            self.female = self.symbols.get_symbol_for_string(self.symbols.SYMBOL_FEMALE)
-            self.bth = self.symbols.get_symbol_for_string(self.symbols.SYMBOL_BIRTH)
-            self.marr = self.symbols.get_symbol_for_string(self.symbols.SYMBOL_MARRIAGE)
+            gsfs = self.symbols.get_symbol_for_string
+            self.male = gsfs(self.symbols.SYMBOL_MALE)
+            self.female = gsfs(self.symbols.SYMBOL_FEMALE)
+            self.bth = gsfs(self.symbols.SYMBOL_BIRTH)
+            self.marr = gsfs(self.symbols.SYMBOL_MARRIAGE)
             self.dth = self.symbols.get_death_symbol_for_char(death_idx)
         else:
             death_idx = self.symbols.DEATH_SYMBOL_LATIN_CROSS
-            self.male = self.symbols.get_symbol_fallback(self.symbols.SYMBOL_MALE)
-            self.female = self.symbols.get_symbol_fallback(self.symbols.SYMBOL_FEMALE)
-            self.marr = self.symbols.get_symbol_fallback(self.symbols.SYMBOL_MARRIAGE)
-            self.bth = self.symbols.get_symbol_fallback(self.symbols.SYMBOL_BIRTH)
+            gsf = self.symbols.get_symbol_fallback
+            self.male = gsf(self.symbols.SYMBOL_MALE)
+            self.female = gsf(self.symbols.SYMBOL_FEMALE)
+            self.marr = gsf(self.symbols.SYMBOL_MARRIAGE)
+            self.bth = gsf(self.symbols.SYMBOL_BIRTH)
             self.dth = self.symbols.get_death_symbol_fallback(death_idx)
 
     def format_relation(self, family, line_count, use_markup=False):
-        """ Format a relation between parents of a family
-        """
+        """Format a relation between parents of a family"""
         if not family:
             return ""
         if use_markup:
@@ -95,7 +96,9 @@ class FormattingHelper:
         marriage = get_marriage_or_fallback(self.dbstate.db, family)
         if marriage and use_markup and marriage.get_type() != EventType.MARRIAGE:
             mdate = "<i>%s %s</i>" % (self.marr, escape(get_date(marriage)))
-            mplace = "<i>%s</i>" % escape(self.get_place_name(marriage.get_place_handle()))
+            mplace = "<i>%s</i>" % escape(
+                self.get_place_name(marriage.get_place_handle())
+            )
             name = "<i>%s</i>" % str(marriage.get_type())
         elif marriage and use_markup:
             mdate = "%s %s" % (self.marr, escape(get_date(marriage)))
@@ -135,8 +138,7 @@ class FormattingHelper:
         return text
 
     def get_place_name(self, place_handle):
-        """ Obtain a place name
-        """
+        """Obtain a place name"""
         text = ""
         if place_handle:
             place = self.dbstate.db.get_place_from_handle(place_handle)
@@ -144,14 +146,13 @@ class FormattingHelper:
                 place_title = place_displayer.display(self.dbstate.db, place)
                 if place_title != "":
                     if len(place_title) > 25:
-                        text = place_title[:24]+"..."
+                        text = place_title[:24] + "..."
                     else:
                         text = place_title
         return text
 
-    def format_person( self, person, line_count, use_markup=False):
-        """fromat how info about a person should be presented
-        """
+    def format_person(self, person, line_count, use_markup=False):
+        """fromat how info about a person should be presented"""
         if not person:
             return ""
         if use_markup:
@@ -169,8 +170,9 @@ class FormattingHelper:
             birth = get_birth_or_fallback(self.dbstate.db, person)
             if birth and use_markup and birth.get_type() != EventType.BIRTH:
                 bdate = "<i>%s</i>" % escape(get_date(birth))
-                bplace = "<i>%s</i>" % escape(self.get_place_name(
-                                                    birth.get_place_handle()))
+                bplace = "<i>%s</i>" % escape(
+                    self.get_place_name(birth.get_place_handle())
+                )
             elif birth and use_markup:
                 bdate = escape(get_date(birth))
                 bplace = escape(self.get_place_name(birth.get_place_handle()))
@@ -183,8 +185,9 @@ class FormattingHelper:
             death = get_death_or_fallback(self.dbstate.db, person)
             if death and use_markup and death.get_type() != EventType.DEATH:
                 ddate = "<i>%s</i>" % escape(get_date(death))
-                dplace = "<i>%s</i>" % escape(self.get_place_name(
-                                                    death.get_place_handle()))
+                dplace = "<i>%s</i>" % escape(
+                    self.get_place_name(death.get_place_handle())
+                )
             elif death and use_markup:
                 ddate = escape(get_date(death))
                 dplace = escape(self.get_place_name(death.get_place_handle()))
@@ -196,12 +199,17 @@ class FormattingHelper:
                 dplace = ""
 
             if line_count < 5:
-                text = "%s\n%s %s\n%s %s" % (name, self.bth, bdate,
-                                             self.dth, ddate)
+                text = "%s\n%s %s\n%s %s" % (name, self.bth, bdate, self.dth, ddate)
             else:
-                text = "%s\n%s %s\n  %s\n%s %s\n  %s" % (name, self.bth, bdate,
-                                                         bplace, self.dth,
-                                                         ddate, dplace)
+                text = "%s\n%s %s\n  %s\n%s %s\n  %s" % (
+                    name,
+                    self.bth,
+                    bdate,
+                    bplace,
+                    self.dth,
+                    ddate,
+                    dplace,
+                )
         if use_markup:
             if not person.handle in self._markup_cache:
                 self._markup_cache[person.handle] = {}
@@ -212,9 +220,8 @@ class FormattingHelper:
             self._text_cache[person.handle][line_count] = text
         return text
 
-    def clear_cache( self):
-        """clear the cache of kept format strings
-        """
+    def clear_cache(self):
+        """clear the cache of kept format strings"""
         self._text_cache = {}
         self._markup_cache = {}
 
@@ -223,6 +230,7 @@ class ImportInfo:
     """
     Class object that can hold information about the import
     """
+
     def __init__(self, default_info=None):
         """
         Init of the import class.
