@@ -17,9 +17,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 # -------------------------------------------------------------------------
@@ -51,7 +50,7 @@ if "-S" in sys.argv or "--safe" in sys.argv:
 # Gramps modules
 #
 # -------------------------------------------------------------------------
-from .gen.const import APP_GRAMPS, USER_DIRLIST, USER_DATA, ORIG_HOME_DIR
+from .gen.const import APP_GRAMPS, USER_DIRLIST, USER_DATA
 from .gen.constfunc import mac
 from .version import VERSION_TUPLE
 from .gen.constfunc import win, get_env_var
@@ -202,7 +201,7 @@ from .gen.mime import mime_type_is_defined
 #
 # -------------------------------------------------------------------------
 
-MIN_PYTHON_VERSION = (3, 8, 0, "", 0)
+MIN_PYTHON_VERSION = (3, 9, 0, "", 0)
 if not sys.version_info >= MIN_PYTHON_VERSION:
     logging.warning(
         _(
@@ -219,6 +218,17 @@ if not sys.version_info >= MIN_PYTHON_VERSION:
     )
     sys.exit(1)
 
+try:
+    import orjson
+except ImportError:
+    logging.warning(
+        _(
+            "The orjson package is needed to start Gramps.\n\n"
+            "Gramps will terminate now."
+        )
+    )
+    sys.exit(1)
+
 # -------------------------------------------------------------------------
 #
 # Gramps libraries
@@ -311,6 +321,17 @@ def show_settings():
     except ImportError:
         pangocairo_str = _("not found")
 
+    try:
+        import orjson
+
+        try:
+            orjson_str = orjson.__version__
+        except:  # any failure to 'get' the version
+            orjson_str = "unknown version"
+
+    except ImportError:
+        orjson_str = "not found"
+
     try:
         from gi import Repository
 
@@ -471,12 +492,10 @@ def show_settings():
     try:
         import sqlite3
 
-        sqlite3_py_version_str = sqlite3.version
         sqlite3_version_str = sqlite3.sqlite_version
         sqlite3_location_str = sqlite3.__file__
     except:
         sqlite3_version_str = "not found"
-        sqlite3_py_version_str = "not found"
         sqlite3_location_str = "not found"
 
     try:
@@ -547,6 +566,7 @@ def show_settings():
     print(" pycairo   : %s" % pycairover_str)
     print(" Pango     : %s" % pangover_str)
     print(" PangoCairo: %s" % pangocairo_str)
+    print(" orjson    : %s" % orjson_str)
     print("")
     print("Recommended:")
     print("------------")
@@ -591,7 +611,6 @@ def show_settings():
     print("     location    : %s" % bsddb_location_str)
     print(" sqlite3   :")
     print("     version     : %s" % sqlite3_version_str)
-    print("     py version  : %s" % sqlite3_py_version_str)
     print("     location    : %s" % sqlite3_location_str)
     print("")
 
@@ -634,11 +653,6 @@ def run():
     argv_copy = sys.argv[:]
     argpars = ArgParser(argv_copy)
 
-    # if in safe mode we should point the db dir back to the original dir.
-    # It is ok to import config here, 'Defaults' command had its chance...
-    if "SAFEMODE" in os.environ:
-        config.set("database.path", os.path.join(ORIG_HOME_DIR, "grampsdb"))
-
     # On windows the fontconfig handler is a better choice
     if win() and ("PANGOCAIRO_BACKEND" not in os.environ):
         os.environ["PANGOCAIRO_BACKEND"] = "fontconfig"
