@@ -17,49 +17,52 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 "Export to GeneWeb."
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python Modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import os
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Set up logging
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 import logging
-import collections
+from collections import abc
+
 log = logging.getLogger(".WriteGeneWeb")
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+
+_ = glocale.translation.gettext
 from gramps.gen.lib import Date, Event, EventType, FamilyRelType, Person
 from gramps.gui.plug.export import WriterOptionBox
 from gramps.gen.utils.alive import probably_alive
 from gramps.gui.glade import Glade
 from gramps.gen.config import config
+from gramps.gen.display.place import displayer as _pd
 
-class GeneWebWriter(object):
+
+class GeneWebWriter:
     def __init__(self, database, filename, user, option_box=None):
         self.db = database
         self.filename = filename
         self.user = user
         self.option_box = option_box
-        if isinstance(self.user.callback, collections.Callable): # callback is really callable
+        if isinstance(self.user.callback, abc.Callable):  # is really callable
             self.update = self.update_real
         else:
             self.update = self.update_empty
@@ -67,7 +70,7 @@ class GeneWebWriter(object):
         self.persons_details_done = []
         self.persons_notes_done = []
         self.person_ids = {}
-        
+
         if option_box:
             self.option_box.parse_options()
             self.db = option_box.get_filtered_database(self.db)
@@ -77,19 +80,32 @@ class GeneWebWriter(object):
 
     def update_real(self):
         self.count += 1
-        newval = int(100*self.count/self.total)
+        newval = int(100 * self.count / self.total)
         if newval != self.oldval:
             self.user.callback(newval)
             self.oldval = newval
 
     def writeln(self, text):
-        self.g.write(self.iso8859('%s\n' % (text)))
+        self.g.write(self.iso8859("%s\n" % (text)))
 
     def export_data(self):
-
-        self.dirname = os.path.dirname (self.filename)
+        self.dirname = os.path.dirname(self.filename)
         try:
-            self.g = open(self.filename, "w")
+            with open(self.filename, "wb") as self.g:
+                self.flist = self.db.get_family_handles()
+                self.flist.sort()
+                if len(self.flist) < 1:
+                    self.user.notify_error(_("No families matched by selected filter"))
+                    return False
+
+                self.count = 0
+                self.oldval = 0
+                self.total = len(self.flist)
+                for key in self.flist:
+                    self.write_family(key)
+                    self.writeln("")
+
+                return True
         except IOError as msg:
             msg2 = _("Could not create %s") % self.filename
             self.user.notify_error(msg2, str(msg))
@@ -98,21 +114,6 @@ class GeneWebWriter(object):
             self.user.notify_error(_("Could not create %s") % self.filename)
             return False
 
-        self.flist = [x for x in self.db.iter_family_handles()]
-        if len(self.flist) < 1:
-            self.notify_error(_("No families matched by selected filter"))
-            return False
-        
-        self.count = 0
-        self.oldval = 0
-        self.total = len(self.flist)
-        for key in self.flist:
-            self.write_family(key)
-            self.writeln("")
-        
-        self.g.close()
-        return True
-    
     def write_family(self, family_handle):
         family = self.db.get_family_from_handle(family_handle)
         if family:
@@ -123,35 +124,37 @@ class GeneWebWriter(object):
                 mother_handle = family.get_mother_handle()
                 if mother_handle:
                     mother = self.db.get_person_from_handle(mother_handle)
-                    self.writeln("fam %s %s+%s %s %s" %
-                            (self.get_ref_name(father), 
-                            self.get_full_person_info_fam(father), 
-                            self.get_wedding_data(family), 
+                    self.writeln(
+                        "fam %s %s+%s %s %s"
+                        % (
+                            self.get_ref_name(father),
+                            self.get_full_person_info_fam(father),
+                            self.get_wedding_data(family),
                             self.get_ref_name(mother),
-                            self.get_full_person_info_fam(mother)
-                            )
-                         )
-                    self.write_witness( family)
-                    self.write_sources( family.get_citation_list())
-                    self.write_children( family, father)
-                    self.write_notes( family, father, mother)
-                    if True: # FIXME: not (self.restrict and self.exclnotes):
+                            self.get_full_person_info_fam(mother),
+                        )
+                    )
+                    self.write_witness(family)
+                    self.write_sources(family.get_citation_list())
+                    self.write_children(family, father)
+                    self.write_notes(family, father, mother)
+                    if True:  # FIXME: not (self.restrict and self.exclnotes):
                         notelist = family.get_note_list()
                         note = ""
                         for notehandle in notelist:
                             noteobj = self.db.get_note_from_handle(notehandle)
                             note += noteobj.get() + " "
                         if note and note != "":
-                            note = note.replace('\n\r',' ')
-                            note = note.replace('\r\n',' ')
-                            note = note.replace('\n',' ')
-                            note = note.replace('\r',' ')
+                            note = note.replace("\n\r", " ")
+                            note = note.replace("\r\n", " ")
+                            note = note.replace("\n", " ")
+                            note = note.replace("\r", " ")
                             self.writeln("comm %s" % note)
-                    
+
     def write_witness(self, family):
         # FIXME: witnesses are not in events anymore
         return
-    
+
         if self.restrict:
             return
         event_ref_list = family.get_event_ref_list()
@@ -162,37 +165,36 @@ class GeneWebWriter(object):
                 if w_list:
                     for witness in w_list:
                         if witness and witness.type == Event.ID:
-                            person = self.db.get_person_from_handle(
-                                                        witness.get_value())
+                            person = self.db.get_person_from_handle(witness.get_value())
                             if person:
                                 gender = ""
                                 if person.get_gender() == Person.MALE:
                                     gender = "h"
                                 elif person.get_gender() == Person.FEMALE:
                                     gender = "f"
-                                self.writeln("wit %s %s %s" % 
-                                        (gender, 
-                                        self.get_ref_name(person), 
-                                        self.get_full_person_info_fam(person)
-                                        )
+                                self.writeln(
+                                    "wit %s %s %s"
+                                    % (
+                                        gender,
+                                        self.get_ref_name(person),
+                                        self.get_full_person_info_fam(person),
                                     )
+                                )
 
-    def write_sources(self,reflist):
+    def write_sources(self, reflist):
         # FIXME
-        #if self.restrict and self.exclnotes:
+        # if self.restrict and self.exclnotes:
         #    return
-            
+
         if reflist:
             for handle in reflist:
                 citation = self.db.get_citation_from_handle(handle)
                 src_handle = citation.get_reference_handle()
                 source = self.db.get_source_from_handle(src_handle)
                 if source:
-                    self.writeln( "src %s" % 
-                        (self.rem_spaces(source.get_title()))
-                        )
+                    self.writeln("src %s" % (self.rem_spaces(source.get_title())))
 
-    def write_children(self,family, father):
+    def write_children(self, family, father):
         father_lastname = father.get_primary_name().get_surname()
         child_ref_list = family.get_child_ref_list()
         if child_ref_list:
@@ -205,19 +207,21 @@ class GeneWebWriter(object):
                         gender = "h"
                     elif child.get_gender() == Person.FEMALE:
                         gender = "f"
-                    self.writeln("- %s %s %s" % 
-                            (gender, 
-                            self.get_child_ref_name(child, father_lastname), 
-                            self.get_full_person_info_child(child)
-                            )
-                         )
+                    self.writeln(
+                        "- %s %s %s"
+                        % (
+                            gender,
+                            self.get_child_ref_name(child, father_lastname),
+                            self.get_full_person_info_child(child),
+                        )
+                    )
             self.writeln("end")
 
-    def write_notes(self,family, father, mother):
+    def write_notes(self, family, father, mother):
         # FIXME:
-        #if self.restrict and self.exclnotes:
+        # if self.restrict and self.exclnotes:
         #    return
-            
+
         self.write_note_of_person(father)
         self.write_note_of_person(mother)
         child_ref_list = family.get_child_ref_list()
@@ -227,22 +231,23 @@ class GeneWebWriter(object):
                 if child:
                     self.write_note_of_person(child)
         # FIXME: witnesses do not exist in events anymore
-##         event_ref_list = family.get_event_ref_list()
-##         for event_ref in event_ref_list:
-##             event = self.db.get_event_from_handle(event_ref.ref)
-##             if int(event.get_type()) == EventType.MARRIAGE:
-##                 w_list = event.get_witness_list()
-##                 if w_list:
-##                     for witness in w_list:
-##                         if witness and witness.type == Event.ID:
-##                             person = self.db.get_person_from_handle(witness.get_value())
-##                             if person:
-##                                 self.write_note_of_person(person)
 
-    def write_note_of_person(self,person):
+    ##         event_ref_list = family.get_event_ref_list()
+    ##         for event_ref in event_ref_list:
+    ##             event = self.db.get_event_from_handle(event_ref.ref)
+    ##             if int(event.get_type()) == EventType.MARRIAGE:
+    ##                 w_list = event.get_witness_list()
+    ##                 if w_list:
+    ##                     for witness in w_list:
+    ##                         if witness and witness.type == Event.ID:
+    ##                             person = self.db.get_person_from_handle(witness.get_value())
+    ##                             if person:
+    ##                                 self.write_note_of_person(person)
+
+    def write_note_of_person(self, person):
         if self.persons_notes_done.count(person.get_handle()) == 0:
             self.persons_notes_done.append(person.get_handle())
-            
+
             notelist = person.get_note_list()
             note = ""
             for notehandle in notelist:
@@ -256,12 +261,12 @@ class GeneWebWriter(object):
                 self.writeln("beg")
                 self.writeln(note)
                 self.writeln("end notes")
-    
+
     def get_full_person_info(self, person):
         # FIXME:
-        #if self.restrict:
+        # if self.restrict:
         #    return "0 "
-            
+
         retval = ""
 
         b_date = "0"
@@ -270,13 +275,12 @@ class GeneWebWriter(object):
         if birth_ref:
             birth = self.db.get_event_from_handle(birth_ref.ref)
             if birth:
-                b_date = self.format_date( birth.get_date_object())
+                b_date = self.format_date(birth.get_date_object())
                 place_handle = birth.get_place_handle()
                 if place_handle:
-                    place = self.db.get_place_from_handle(place_handle)
-                    b_place = place.get_title()
-        
-        if probably_alive(person,self.db):
+                    b_place = _pd.display_event(self.db, birth)
+
+        if probably_alive(person, self.db):
             d_date = ""
         else:
             d_date = "0"
@@ -285,12 +289,11 @@ class GeneWebWriter(object):
         if death_ref:
             death = self.db.get_event_from_handle(death_ref.ref)
             if death:
-                d_date = self.format_date( death.get_date_object())
+                d_date = self.format_date(death.get_date_object())
                 place_handle = death.get_place_handle()
                 if place_handle:
-                    place = self.db.get_place_from_handle(place_handle)
-                    d_place = place.get_title()
-            
+                    d_place = _pd.display_event(self.db, death)
+
         retval = retval + "%s " % b_date
         if b_place != "":
             retval = retval + "#bp %s " % self.rem_spaces(b_place)
@@ -301,9 +304,9 @@ class GeneWebWriter(object):
 
     def get_full_person_info_fam(self, person):
         """Output full person data of a family member.
-        
+
         This is only done if the person is not listed as a child.
-         
+
         """
         retval = ""
         if self.persons_details_done.count(person.get_handle()) == 0:
@@ -317,7 +320,6 @@ class GeneWebWriter(object):
                 self.persons_details_done.append(person.get_handle())
                 retval = self.get_full_person_info(person)
         return retval
-                    
 
     def get_full_person_info_child(self, person):
         """Output full person data for a child, if not printed somewhere else."""
@@ -327,36 +329,36 @@ class GeneWebWriter(object):
             retval = self.get_full_person_info(person)
         return retval
 
-    def rem_spaces(self,str):
-        return str.replace(' ','_')
-    
-    def get_ref_name(self,person):
-        #missing_surname = config.get("preferences.no-surname-text")
-        surname = self.rem_spaces( person.get_primary_name().get_surname())
-        #firstname = config.get('preferences.private-given-text') 
-        #if not (probably_alive(person,self.db) and \
+    def rem_spaces(self, str):
+        return str.replace(" ", "_")
+
+    def get_ref_name(self, person):
+        # missing_surname = config.get("preferences.no-surname-text")
+        surname = self.rem_spaces(person.get_primary_name().get_surname())
+        # firstname = config.get('preferences.private-given-text')
+        # if not (probably_alive(person,self.db) and \
         #  self.restrict and self.living):
-        firstname = self.rem_spaces( person.get_primary_name().get_first_name())
+        firstname = self.rem_spaces(person.get_primary_name().get_first_name())
         if person.get_handle() not in self.person_ids:
             self.person_ids[person.get_handle()] = len(self.person_ids)
-        return "%s %s.%d" % (surname, firstname, 
-                             self.person_ids[person.get_handle()])
+        return "%s %s.%d" % (surname, firstname, self.person_ids[person.get_handle()])
 
-    def get_child_ref_name(self,person,father_lastname):
-        #missing_first_name = config.get("preferences.no-given-text")
-        surname = self.rem_spaces( person.get_primary_name().get_surname())
-        #firstname = config.get('preferences.private-given-text')
-        #if not (probably_alive(person,self.db) and \
+    def get_child_ref_name(self, person, father_lastname):
+        # missing_first_name = config.get("preferences.no-given-text")
+        surname = self.rem_spaces(person.get_primary_name().get_surname())
+        # firstname = config.get('preferences.private-given-text')
+        # if not (probably_alive(person,self.db) and \
         #  self.restrict and self.living):
-        firstname = self.rem_spaces( person.get_primary_name().get_first_name())
+        firstname = self.rem_spaces(person.get_primary_name().get_first_name())
         if person.get_handle() not in self.person_ids:
             self.person_ids[person.get_handle()] = len(self.person_ids)
         ret = "%s.%d" % (firstname, self.person_ids[person.get_handle()])
-        if surname != father_lastname: ret += " " + surname
+        if surname != father_lastname:
+            ret += " " + surname
         return ret
 
-    def get_wedding_data(self,family):
-        ret = "";
+    def get_wedding_data(self, family):
+        ret = ""
         event_ref_list = family.get_event_ref_list()
         m_date = ""
         m_place = ""
@@ -372,42 +374,46 @@ class GeneWebWriter(object):
             event = self.db.get_event_from_handle(event_ref.ref)
             if event.get_type() == EventType.MARRIAGE:
                 married = 1
-                m_date = self.format_date( event.get_date_object())
+                m_date = self.format_date(event.get_date_object())
                 place_handle = event.get_place_handle()
                 if place_handle:
-                    place = self.db.get_place_from_handle(place_handle)
-                    m_place = place.get_title()
-                m_source = self.get_primary_source( event.get_citation_list())
+                    m_place = _pd.display_event(self.db, event)
+                m_source = self.get_primary_source(event.get_citation_list())
             if event.get_type() == EventType.ENGAGEMENT:
                 engaged = 1
-                eng_date = self.format_date( event.get_date_object())
+                eng_date = self.format_date(event.get_date_object())
                 place_handle = event.get_place_handle()
                 if place_handle:
-                    place = self.db.get_place_from_handle(place_handle)
-                    eng_place = place.get_title()
-                eng_source = self.get_primary_source( event.get_citation_list())
+                    eng_place = _pd.display_event(self.db, event)
+                eng_source = self.get_primary_source(event.get_citation_list())
             if event.get_type() == EventType.DIVORCE:
                 divorced = 1
-                div_date = self.format_date( event.get_date_object())
+                div_date = self.format_date(event.get_date_object())
         if married == 1:
             if m_date != "":
                 ret = ret + m_date
             if m_place != "" and m_source != "":
-                ret = ret + " #mp %s #ms %s" % (self.rem_spaces( m_place), self.rem_spaces( m_source))
+                ret = ret + " #mp %s #ms %s" % (
+                    self.rem_spaces(m_place),
+                    self.rem_spaces(m_source),
+                )
             if m_place != "" and m_source == "":
-                ret = ret + " #mp %s" % self.rem_spaces( m_place)
+                ret = ret + " #mp %s" % self.rem_spaces(m_place)
             if m_source != "" and m_place == "":
-                ret = ret + " #ms %s" % self.rem_spaces( m_source)
+                ret = ret + " #ms %s" % self.rem_spaces(m_source)
         elif engaged == 1:
             """Geneweb only supports either Marriage or engagement"""
             if eng_date != "":
                 ret = ret + eng_date
             if m_place != "" and m_source != "":
-                ret = ret + " #mp %s #ms %s" % (self.rem_spaces( m_place), self.rem_spaces( m_source))
+                ret = ret + " #mp %s #ms %s" % (
+                    self.rem_spaces(m_place),
+                    self.rem_spaces(m_source),
+                )
             if eng_place != "" and m_source == "":
-                ret = ret + " #mp %s" % self.rem_spaces( m_place)
+                ret = ret + " #mp %s" % self.rem_spaces(m_place)
             if eng_source != "" and m_place == "":
-                ret = ret + " #ms %s" % self.rem_spaces( m_source)
+                ret = ret + " #ms %s" % self.rem_spaces(m_source)
         else:
             if family.get_relationship() != FamilyRelType.MARRIED:
                 """Not married or engaged"""
@@ -415,13 +421,13 @@ class GeneWebWriter(object):
 
         if divorced == 1:
             if div_date != "":
-                ret = ret + " -%s" %div_date
+                ret = ret + " -%s" % div_date
             else:
                 ret = ret + " -0"
 
         return ret
 
-    def get_primary_source(self,reflist):
+    def get_primary_source(self, reflist):
         ret = ""
         if reflist:
             for handle in reflist:
@@ -433,11 +439,11 @@ class GeneWebWriter(object):
                         ret = ret + ", "
                         ret = ret + source.get_title()
         return ret
-    
+
     def format_single_date(self, subdate, cal, mode):
         retval = ""
         (day, month, year, sl) = subdate
-        
+
         cal_type = ""
         if cal == Date.CAL_HEBREW:
             cal_type = "H"
@@ -445,7 +451,7 @@ class GeneWebWriter(object):
             cal_type = "F"
         elif cal == Date.CAL_JULIAN:
             cal_type = "J"
-        
+
         mode_prefix = ""
         if mode == Date.MOD_ABOUT:
             mode_prefix = "~"
@@ -453,19 +459,18 @@ class GeneWebWriter(object):
             mode_prefix = "<"
         elif mode == Date.MOD_AFTER:
             mode_prefix = ">"
-            
+
         if year > 0:
             if month > 0:
                 if day > 0:
-                    retval = "%s%s/%s/%s%s" % (mode_prefix,day,month,year,cal_type)
+                    retval = "%s%s/%s/%s%s" % (mode_prefix, day, month, year, cal_type)
                 else:
-                    retval = "%s%s/%s%s" % (mode_prefix,month,year,cal_type)
+                    retval = "%s%s/%s%s" % (mode_prefix, month, year, cal_type)
             else:
-                retval = "%s%s%s" % (mode_prefix,year,cal_type)
+                retval = "%s%s%s" % (mode_prefix, year, cal_type)
         return retval
 
-    
-    def format_date(self,date):
+    def format_date(self, date):
         retval = ""
         if date.get_modifier() == Date.MOD_TEXTONLY:
             retval = "0(%s)" % self.rem_spaces(date.get_text())
@@ -474,20 +479,30 @@ class GeneWebWriter(object):
             cal = cal = date.get_calendar()
             if mod == Date.MOD_SPAN or mod == Date.MOD_RANGE:
                 retval = "%s..%s" % (
-                    self.format_single_date(date.get_start_date(), cal,mod),
-                    self.format_single_date(date.get_stop_date(),cal,mod))
+                    self.format_single_date(date.get_start_date(), cal, mod),
+                    self.format_single_date(date.get_stop_date(), cal, mod),
+                )
+            elif mod == Date.MOD_FROM:
+                retval = "%s..0" % (
+                    self.format_single_date(date.get_start_date(), cal, mod)
+                )
+            elif mod == Date.MOD_TO:
+                retval = "0..%s" % (
+                    self.format_single_date(date.get_start_date(), cal, mod)
+                )
             else:
-                retval = self.format_single_date(date.get_start_date(),cal,mod)
+                retval = self.format_single_date(date.get_start_date(), cal, mod)
         return retval
 
-    def iso8859(self,s):
-        return s.encode('iso-8859-1','xmlcharrefreplace')
+    def iso8859(self, s):
+        return s.encode("iso-8859-1", "xmlcharrefreplace")
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 #
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def exportData(database, filename, user, option_box=None):
     gw = GeneWebWriter(database, filename, user, option_box)
     return gw.export_data()
