@@ -13,9 +13,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 # -------------------------------------------------------------------------
@@ -138,6 +137,7 @@ class Citations(Gramplet, DbGUIElement):
 
     def add_eventref_citations(self, obj):
         for event_ref in obj.get_event_ref_list():
+            self.add_citations(event_ref)
             self.add_attribute_citations(event_ref)
             event = self.dbstate.db.get_event_from_handle(event_ref.ref)
             self.add_event_citations(event)
