@@ -13,9 +13,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 
 ## Based on the paper:
 ##   http://www.cs.utah.edu/~draperg/research/fanchart/draperg_FHT08.pdf
@@ -25,20 +24,20 @@
 ## Found by redwood:
 ## http://www.gramps-project.org/bugs/view.php?id=2611
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from gi.repository import Gtk
 import cairo
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 import gramps.gui.widgets.fanchart as fanchart
 import gramps.gui.widgets.fanchartdesc as fanchartdesc
 from gramps.gui.views.navigationview import NavigationView
@@ -50,67 +49,75 @@ from gramps.plugins.view.fanchartview import FanChartView
 PRINT_SETTINGS = None
 _ = glocale.translation.gettext
 
+
 class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
     """
     The Gramplet code that realizes the FanChartWidget.
     """
-    #settings in the config file
+
+    # settings in the config file
     CONFIGSETTINGS = (
-        ('interface.fanview-maxgen', 9),
-        ('interface.fanview-background', fanchart.BACKGROUND_GRAD_GEN),
-        ('interface.fanview-radialtext', True),
-        ('interface.fanview-twolinename', True),
-        ('interface.fanview-flipupsidedownname', True),
-        ('interface.fanview-font', 'Sans'),
-        ('interface.fanview-form', fanchart.FORM_CIRCLE),
-        ('interface.color-start-grad', '#ef2929'),
-        ('interface.color-end-grad', '#3d37e9'),
-        ('interface.angle-algorithm', fanchartdesc.ANGLE_WEIGHT),
-        ('interface.duplicate-color', '#888a85'),
-        ('interface.fanview-showid', False)
-        )
+        ("interface.fanview-maxgen", 9),
+        ("interface.fanview-background", fanchart.BACKGROUND_GRAD_GEN),
+        ("interface.fanview-radialtext", True),
+        ("interface.fanview-twolinename", True),
+        ("interface.fanview-flipupsidedownname", True),
+        ("interface.fanview-font", "Sans"),
+        ("interface.fanview-form", fanchart.FORM_CIRCLE),
+        ("interface.color-start-grad", "#ef2929"),
+        ("interface.color-end-grad", "#3d37e9"),
+        ("interface.angle-algorithm", fanchartdesc.ANGLE_WEIGHT),
+        ("interface.duplicate-color", "#888a85"),
+        ("interface.fanview-showid", False),
+    )
+
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         self.dbstate = dbstate
         self.uistate = uistate
 
-        NavigationView.__init__(self, _('Descendant Fan Chart'),
-                                pdata, dbstate, uistate,
-                                PersonBookmarks, nav_group)
-        fanchartdesc.FanChartDescGrampsGUI.__init__(self,
-                                                    self.on_childmenu_changed)
-        #set needed values
+        NavigationView.__init__(
+            self,
+            _("Descendant Fan Chart"),
+            pdata,
+            dbstate,
+            uistate,
+            PersonBookmarks,
+            nav_group,
+        )
+        fanchartdesc.FanChartDescGrampsGUI.__init__(self, self.on_childmenu_changed)
+        # set needed values
         scg = self._config.get
-        self.maxgen = scg('interface.fanview-maxgen')
-        self.background = scg('interface.fanview-background')
-        self.radialtext = scg('interface.fanview-radialtext')
-        self.twolinename = scg('interface.fanview-twolinename')
-        self.flipupsidedownname = scg('interface.fanview-flipupsidedownname')
-        self.fonttype = scg('interface.fanview-font')
+        self.maxgen = scg("interface.fanview-maxgen")
+        self.background = scg("interface.fanview-background")
+        self.radialtext = scg("interface.fanview-radialtext")
+        self.twolinename = scg("interface.fanview-twolinename")
+        self.flipupsidedownname = scg("interface.fanview-flipupsidedownname")
+        self.fonttype = scg("interface.fanview-font")
 
-        self.grad_start = scg('interface.color-start-grad')
-        self.grad_end = scg('interface.color-end-grad')
-        self.form = scg('interface.fanview-form')
-        self.angle_algo = scg('interface.angle-algorithm')
-        self.dupcolor = scg('interface.duplicate-color')
-        self.showid = scg('interface.fanview-showid')
+        self.grad_start = scg("interface.color-start-grad")
+        self.grad_end = scg("interface.color-end-grad")
+        self.form = scg("interface.fanview-form")
+        self.angle_algo = scg("interface.angle-algorithm")
+        self.dupcolor = scg("interface.duplicate-color")
+        self.showid = scg("interface.fanview-showid")
         self.generic_filter = None
         self.alpha_filter = 0.2
         self.scrolledwindow = None
 
-        dbstate.connect('active-changed', self.active_changed)
-        dbstate.connect('database-changed', self.change_db)
+        dbstate.connect("active-changed", self.active_changed)
+        dbstate.connect("database-changed", self.change_db)
 
         self.additional_uis.append(FanChartView.additional_ui)
         self.allfonts = [x for x in enumerate(SystemFonts().get_system_fonts())]
 
-        self.uistate.connect('font-changed', self.font_changed)
+        self.uistate.connect("font-changed", self.font_changed)
 
     def font_changed(self):
         self.format_helper.reload_symbols()
         self.update()
 
     def navigation_type(self):
-        return 'Person'
+        return "Person"
 
     def get_handle_from_gramps_id(self, gid):
         """
@@ -123,12 +130,13 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
             return None
 
     def build_widget(self):
-        self.set_fan(fanchartdesc.FanChartDescWidget(self.dbstate, self.uistate,
-                                                     self.on_popup))
-        self.scrolledwindow = Gtk.ScrolledWindow(hadjustment=None,
-                                                 vadjustment=None)
-        self.scrolledwindow.set_policy(Gtk.PolicyType.AUTOMATIC,
-                                       Gtk.PolicyType.AUTOMATIC)
+        self.set_fan(
+            fanchartdesc.FanChartDescWidget(self.dbstate, self.uistate, self.on_popup)
+        )
+        self.scrolledwindow = Gtk.ScrolledWindow(hadjustment=None, vadjustment=None)
+        self.scrolledwindow.set_policy(
+            Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC
+        )
         self.fan.show_all()
         self.scrolledwindow.add(self.fan)
 
@@ -138,12 +146,11 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         The category stock icon
         """
-        return 'gramps-pedigree'
+        return "gramps-pedigree"
 
     def get_viewtype_stock(self):
-        """Type of view in category
-        """
-        return 'gramps-fanchart'
+        """Type of view in category"""
+        return "gramps-fanchart"
 
     def define_actions(self):
         """
@@ -152,8 +159,8 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         NavigationView.define_actions(self)
 
-        self._add_action('PrintView', self.printview, "<PRIMARY><SHIFT>P")
-        self._add_action('PRIMARY-J', self.jump, '<PRIMARY>J')
+        self._add_action("PrintView", self.printview, "<PRIMARY><SHIFT>P")
+        self._add_action("PRIMARY-J", self.jump, "<PRIMARY>J")
 
     def build_tree(self):
         """
@@ -177,14 +184,14 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         Connect database signals.
         """
-        self._add_db_signal('person-add', self.person_rebuild)
-        self._add_db_signal('person-update', self.person_rebuild)
-        self._add_db_signal('person-delete', self.person_rebuild)
-        self._add_db_signal('person-rebuild', self.person_rebuild_bm)
-        self._add_db_signal('family-update', self.person_rebuild)
-        self._add_db_signal('family-add', self.person_rebuild)
-        self._add_db_signal('family-delete', self.person_rebuild)
-        self._add_db_signal('family-rebuild', self.person_rebuild)
+        self._add_db_signal("person-add", self.person_rebuild)
+        self._add_db_signal("person-update", self.person_rebuild)
+        self._add_db_signal("person-delete", self.person_rebuild)
+        self._add_db_signal("person-rebuild", self.person_rebuild_bm)
+        self._add_db_signal("family-update", self.person_rebuild)
+        self._add_db_signal("family-add", self.person_rebuild)
+        self._add_db_signal("family-delete", self.person_rebuild)
+        self._add_db_signal("family-rebuild", self.person_rebuild)
 
     def change_db(self, db):
         """
@@ -209,8 +216,7 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         self.main()
 
     def get_active(self, obj):
-        """overrule get_active, to support call as in Gramplets
-        """
+        """overrule get_active, to support call as in Gramplets"""
         dummy_obj = obj
         return NavigationView.get_active(self)
 
@@ -241,13 +247,12 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
             heightpx = heightpx / 2 + self.fan.CENTER + fanchart.PAD_PX
             widthpx = heightpx
 
-        prt = CairoPrintSave(widthpx, heightpx, self.fan.prt_draw,
-                             self.uistate.window)
+        prt = CairoPrintSave(widthpx, heightpx, self.fan.prt_draw, self.uistate.window)
         prt.run()
 
     def on_childmenu_changed(self, obj, person_handle):
         """Callback for the pulldown menu selection, changing to the person
-           attached with menu item."""
+        attached with menu item."""
         dummy_obj = obj
         self.change_active(person_handle)
         return True
@@ -277,72 +282,107 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         grid.set_column_spacing(6)
         grid.set_row_spacing(6)
 
-        configdialog.add_spinner(grid, _("Max generations"), 0,
-                                 'interface.fanview-maxgen', (2, 16),
-                                 callback=self.cb_update_maxgen)
-        configdialog.add_combo(grid, _('Text Font'),
-                               1, 'interface.fanview-font',
-                               self.allfonts, callback=self.cb_update_font,
-                               valueactive=True)
+        configdialog.add_spinner(
+            grid,
+            _("Max generations"),
+            0,
+            "interface.fanview-maxgen",
+            (2, 16),
+            callback=self.cb_update_maxgen,
+        )
+        configdialog.add_combo(
+            grid,
+            _("Text Font"),
+            1,
+            "interface.fanview-font",
+            self.allfonts,
+            callback=self.cb_update_font,
+            valueactive=True,
+        )
         backgrvals = (
-            (fanchart.BACKGROUND_GENDER, _('Gender colors')),
-            (fanchart.BACKGROUND_GRAD_GEN, _('Generation based gradient')),
-            (fanchart.BACKGROUND_GRAD_AGE, _('Age (0-100) based gradient')),
-            (fanchart.BACKGROUND_SINGLE_COLOR,
-	            _('Single main (filter) color')),
-            (fanchart.BACKGROUND_GRAD_PERIOD, _('Time period based gradient')),
-            (fanchart.BACKGROUND_WHITE, _('White')),
-            (fanchart.BACKGROUND_SCHEME1, _('Color scheme classic report')),
-            (fanchart.BACKGROUND_SCHEME2, _('Color scheme classic view')),
-            )
-        curval = self._config.get('interface.fanview-background')
+            (fanchart.BACKGROUND_GENDER, _("Gender colors")),
+            (fanchart.BACKGROUND_GRAD_GEN, _("Generation based gradient")),
+            (fanchart.BACKGROUND_GRAD_AGE, _("Age (0-100) based gradient")),
+            (fanchart.BACKGROUND_SINGLE_COLOR, _("Single main (filter) color")),
+            (fanchart.BACKGROUND_GRAD_PERIOD, _("Time period based gradient")),
+            (fanchart.BACKGROUND_WHITE, _("White")),
+            (fanchart.BACKGROUND_SCHEME1, _("Color scheme classic report")),
+            (fanchart.BACKGROUND_SCHEME2, _("Color scheme classic view")),
+        )
+        curval = self._config.get("interface.fanview-background")
         nrval = 0
         for nbr, dummy_val in backgrvals:
             if curval == nbr:
                 break
             nrval += 1
-        configdialog.add_combo(grid, _('Background'),
-                               2, 'interface.fanview-background',
-                               backgrvals, callback=self.cb_update_background,
-                               valueactive=False, setactive=nrval)
-        #colors, stored as hex values
-        configdialog.add_color(grid, _('Start gradient/Main color'), 3,
-                               'interface.color-start-grad', col=1)
-        configdialog.add_color(grid, _('End gradient/2nd color'), 4,
-                               'interface.color-end-grad', col=1)
-        configdialog.add_color(grid, _('Color for duplicates'), 5,
-                               'interface.duplicate-color', col=1)
+        configdialog.add_combo(
+            grid,
+            _("Background"),
+            2,
+            "interface.fanview-background",
+            backgrvals,
+            callback=self.cb_update_background,
+            valueactive=False,
+            setactive=nrval,
+        )
+        # colors, stored as hex values
+        configdialog.add_color(
+            grid, _("Start gradient/Main color"), 3, "interface.color-start-grad", col=1
+        )
+        configdialog.add_color(
+            grid, _("End gradient/2nd color"), 4, "interface.color-end-grad", col=1
+        )
+        configdialog.add_color(
+            grid, _("Color for duplicates"), 5, "interface.duplicate-color", col=1
+        )
         # form of the fan
-        configdialog.add_combo(grid, _('Fan chart type'), 6,
-                               'interface.fanview-form',
-                               ((fanchart.FORM_CIRCLE, _('Full Circle')),
-                                (fanchart.FORM_HALFCIRCLE, _('Half Circle')),
-                                (fanchart.FORM_QUADRANT, _('Quadrant'))),
-                               callback=self.cb_update_form)
+        configdialog.add_combo(
+            grid,
+            _("Fan chart type"),
+            6,
+            "interface.fanview-form",
+            (
+                (fanchart.FORM_CIRCLE, _("Full Circle")),
+                (fanchart.FORM_HALFCIRCLE, _("Half Circle")),
+                (fanchart.FORM_QUADRANT, _("Quadrant")),
+            ),
+            callback=self.cb_update_form,
+        )
         # algo for the fan angle distribution
-        configdialog.add_combo(grid, _('Fan chart distribution'), 7,
-                               'interface.angle-algorithm',
-                               ((fanchartdesc.ANGLE_CHEQUI,
-                                 _('Homogeneous children distribution')),
-                                (fanchartdesc.ANGLE_WEIGHT,
-                                 _('Size proportional to number'
-                                   ' of descendants')),
-                               ),
-                               callback=self.cb_update_anglealgo)
+        configdialog.add_combo(
+            grid,
+            _("Fan chart distribution"),
+            7,
+            "interface.angle-algorithm",
+            (
+                (fanchartdesc.ANGLE_CHEQUI, _("Homogeneous children distribution")),
+                (
+                    fanchartdesc.ANGLE_WEIGHT,
+                    _("Size proportional to number" " of descendants"),
+                ),
+            ),
+            callback=self.cb_update_anglealgo,
+        )
 
         # show names one two line
-        configdialog.add_checkbox(grid, _('Show names on two lines'),
-                                  8, 'interface.fanview-twolinename')
+        configdialog.add_checkbox(
+            grid, _("Show names on two lines"), 8, "interface.fanview-twolinename"
+        )
 
         # Flip names
-        configdialog.add_checkbox(grid, _('Flip name on the left of the fan'),
-                                  9, 'interface.fanview-flipupsidedownname')
+        configdialog.add_checkbox(
+            grid,
+            _("Flip name on the left of the fan"),
+            9,
+            "interface.fanview-flipupsidedownname",
+        )
 
         # show gramps_id
-        configdialog.add_checkbox(grid, _('Show gramps id'),
-                                  10, 'interface.fanview-showid')
+        configdialog.add_checkbox(
+            grid, _("Show gramps id"), 10, "interface.fanview-showid"
+        )
 
-        return _('Layout'), grid
+        return _("Layout"), grid
 
     def config_connect(self):
         """
@@ -350,18 +390,16 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         This method will be called after the ini file is initialized,
         use it to monitor changes in the ini file
         """
-        self._config.connect('interface.color-start-grad',
-                             self.cb_update_color)
-        self._config.connect('interface.color-end-grad',
-                             self.cb_update_color)
-        self._config.connect('interface.duplicate-color',
-                             self.cb_update_color)
-        self._config.connect('interface.fanview-flipupsidedownname',
-                             self.cb_update_flipupsidedownname)
-        self._config.connect('interface.fanview-twolinename',
-                             self.cb_update_twolinename)
-        self._config.connect('interface.fanview-showid',
-                             self.cb_update_showid)
+        self._config.connect("interface.color-start-grad", self.cb_update_color)
+        self._config.connect("interface.color-end-grad", self.cb_update_color)
+        self._config.connect("interface.duplicate-color", self.cb_update_color)
+        self._config.connect(
+            "interface.fanview-flipupsidedownname", self.cb_update_flipupsidedownname
+        )
+        self._config.connect(
+            "interface.fanview-twolinename", self.cb_update_twolinename
+        )
+        self._config.connect("interface.fanview-showid", self.cb_update_showid)
 
     def cb_update_maxgen(self, spinbtn, constant):
         """
@@ -375,7 +413,7 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         Called when the configuration menu changes the twolinename setting.
         """
-        self.twolinename = (entry == 'True')
+        self.twolinename = entry == "True"
         self.update()
 
     def cb_update_background(self, obj, constant):
@@ -383,9 +421,12 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         Change the background
         """
         entry = obj.get_active()
-        Gtk.TreePath.new_from_string('%d' % entry)
-        val = int(obj.get_model().get_value(
-            obj.get_model().get_iter_from_string('%d' % entry), 0))
+        Gtk.TreePath.new_from_string("%d" % entry)
+        val = int(
+            obj.get_model().get_value(
+                obj.get_model().get_iter_from_string("%d" % entry), 0
+            )
+        )
         self._config.set(constant, val)
         self.background = val
         self.update()
@@ -412,9 +453,9 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         Called when the configuration menu changes the childrenring setting.
         """
-        self.grad_start = self._config.get('interface.color-start-grad')
-        self.grad_end = self._config.get('interface.color-end-grad')
-        self.dupcolor = self._config.get('interface.duplicate-color')
+        self.grad_start = self._config.get("interface.color-start-grad")
+        self.grad_end = self._config.get("interface.color-end-grad")
+        self.dupcolor = self._config.get("interface.duplicate-color")
         self.update()
 
     def cb_update_flipupsidedownname(self, client, cnxn_id, entry, data):
@@ -422,14 +463,14 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         Called when the configuration menu changes the
         flipupsidedownname setting.
         """
-        self.flipupsidedownname = (entry == 'True')
+        self.flipupsidedownname = entry == "True"
         self.update()
 
     def cb_update_showid(self, client, cnxn_id, entry, data):
         """
         Called when the configuration menu changes the showid setting.
         """
-        self.showid = (entry == 'True')
+        self.showid = entry == "True"
         self.update()
 
     def cb_update_font(self, obj, constant):
@@ -445,14 +486,14 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         Define the default gramplets for the sidebar and bottombar.
         """
-        return (("Person Filter",),
-                ())
+        return (("Person Filter",), ())
 
-#------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------
 #
 # CairoPrintSave class
 #
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 class CairoPrintSave:
     """Act as an abstract document that can render onto a cairo context.
 
@@ -474,9 +515,7 @@ class CairoPrintSave:
         self.previewopr = None
 
     def run(self):
-        """Create the physical output from the meta document.
-
-        """
+        """Create the physical output from the meta document."""
         global PRINT_SETTINGS
 
         # set up a print operation
@@ -485,19 +524,21 @@ class CairoPrintSave:
         operation.connect("preview", self.on_preview)
         operation.connect("paginate", self.on_paginate)
         operation.set_n_pages(1)
-        #paper_size = Gtk.PaperSize.new(name="iso_a4")
+        # paper_size = Gtk.PaperSize.new(name="iso_a4")
         ## WHY no Gtk.Unit.PIXEL ?? Is there a better way to convert
         ## Pixels to MM ??
-        paper_size = Gtk.PaperSize.new_custom("custom",
-                                              "Custom Size",
-                                              round(self.widthpx * 0.2646),
-                                              round(self.heightpx * 0.2646),
-                                              Gtk.Unit.MM)
+        paper_size = Gtk.PaperSize.new_custom(
+            "custom",
+            "Custom Size",
+            round(self.widthpx * 0.2646),
+            round(self.heightpx * 0.2646),
+            Gtk.Unit.MM,
+        )
         page_setup = Gtk.PageSetup()
         page_setup.set_paper_size(paper_size)
-        #page_setup.set_orientation(Gtk.PageOrientation.PORTRAIT)
+        # page_setup.set_orientation(Gtk.PageOrientation.PORTRAIT)
         operation.set_default_page_setup(page_setup)
-        #operation.set_use_full_page(True)
+        # operation.set_use_full_page(True)
 
         if PRINT_SETTINGS is not None:
             operation.set_print_settings(PRINT_SETTINGS)
@@ -505,9 +546,8 @@ class CairoPrintSave:
         # run print dialog
         while True:
             self.preview = None
-            res = operation.run(Gtk.PrintOperationAction.PRINT_DIALOG,
-                                self.parent)
-            if self.preview is None: # cancel or print
+            res = operation.run(Gtk.PrintOperationAction.PRINT_DIALOG, self.parent)
+            if self.preview is None:  # cancel or print
                 break
             # set up printing again; can't reuse PrintOperation?
             operation = Gtk.PrintOperation()
@@ -524,24 +564,23 @@ class CairoPrintSave:
             PRINT_SETTINGS = operation.get_print_settings()
 
     def on_draw_page(self, operation, context, page_nr):
-        """Draw a page on a Cairo context.
-        """
+        """Draw a page on a Cairo context."""
         dummy_operation = operation
         dummy_page_nr = page_nr
         ctx = context.get_cairo_context()
         pxwidth = round(context.get_width())
         pxheight = round(context.get_height())
-        scale = min(pxwidth/self.widthpx, pxheight/self.heightpx)
+        scale = min(pxwidth / self.widthpx, pxheight / self.heightpx)
         self.drawfunc(None, ctx, scale=scale)
 
     def on_paginate(self, operation, context):
         """Paginate the whole document in chunks.
-           We don't need this as there is only one page, however,
-           we provide a dummy holder here, because on_preview crashes if no
-           default application is set with gir 3.3.2
-           (typically evince not installed)!
-           It will provide the start of the preview dialog, which cannot be
-           started in on_preview
+        We don't need this as there is only one page, however,
+        we provide a dummy holder here, because on_preview crashes if no
+        default application is set with gir 3.3.2
+        (typically evince not installed)!
+        It will provide the start of the preview dialog, which cannot be
+        started in on_preview
         """
         dummy_context = context
         finished = True
@@ -556,21 +595,23 @@ class CairoPrintSave:
 
     def on_preview(self, operation, preview, context, parent):
         """Implement custom print preview functionality.
-           We provide a dummy holder here, because on_preview crashes if no
-           default application is set with gir 3.3.2
-           (typically evince not installed)!
+        We provide a dummy holder here, because on_preview crashes if no
+        default application is set with gir 3.3.2
+        (typically evince not installed)!
         """
         dummy_preview = preview
-        dlg = Gtk.MessageDialog(parent,
-                                flags=Gtk.DialogFlags.MODAL,
-                                type=Gtk.MessageType.WARNING,
-                                buttons=Gtk.ButtonsType.CLOSE,
-                                message_format=_('No preview available'))
+        dlg = Gtk.MessageDialog(
+            transient_for=parent,
+            modal=True,
+            message_type=Gtk.MessageType.WARNING,
+            buttons=Gtk.ButtonsType.CLOSE,
+            message_format=_("No preview available"),
+        )
         self.preview = dlg
         self.previewopr = operation
-        #dlg.format_secondary_markup(msg2)
+        # dlg.format_secondary_markup(msg2)
         dlg.set_title("Fan Chart Preview - Gramps")
-        dlg.connect('response', self.previewdestroy)
+        dlg.connect("response", self.previewdestroy)
 
         # give a dummy cairo context to Gtk.PrintContext,
         try:
