@@ -28,9 +28,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -407,6 +406,10 @@ class MediaPages(BasePage):
             target_exists = newpath is not None
         else:
             target_exists = False
+        remote_target = False
+        path = media.get_path()
+        if path.startswith(("http://", "https://")):
+            remote_target = media.get_path()
 
         self.copy_thumbnail(media_handle, media)
         self.page_title = media.get_description()
@@ -450,6 +453,14 @@ class MediaPages(BasePage):
 
             # missing media error message
             errormsg = self._("The file has been moved or deleted.")
+            if remote_target:
+                ttlen = self._("This is a remote media")
+                descr = media.get_description()
+                if not descr:
+                    descr = remote_target
+                errormsg = Html(
+                    "a", descr, href=remote_target, title=ttlen, target="_remote"
+                )
 
             # begin summaryarea division
             with Html("div", id="summaryarea") as summaryarea:
