@@ -16,9 +16,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -254,7 +253,7 @@ class UpdatesPage(BasePage):
                                             show = True
                                 elif obj_t == "Citation":
                                     if r_handle in srbkref[Citation]:
-                                        cit = srbd.get_event_from_handle(r_handle)
+                                        cit = srbd.get_citation_from_handle(r_handle)
                                         citsrc = cit.source_handle
                                         evtn = self._("Citation")
                                         name = self.source_link(citsrc, evtn)
