@@ -14,31 +14,32 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
 # plugins/webstuff/webstuff.gpr.py
 
-MODULE_VERSION="5.1"
+MODULE_VERSION = "6.0"
 
-#------------------------------------------------------------------------
+# ------------------------------------------------------------------------
 #
 # Stylesheets
 #
-#------------------------------------------------------------------------
-register(GENERAL,
-id = 'system webstuff',
-category = "WEBSTUFF",
-name = _("Webstuff"),
-description = _("Provides a collection of resources for the web"),
-version = '1.0',
-gramps_target_version = MODULE_VERSION,
-fname = "webstuff.py",
-load_on_reg = True,
-process = "process_list",
-status = STABLE
-  )
+# ------------------------------------------------------------------------
+register(
+    GENERAL,
+    id="system webstuff",
+    category="WEBSTUFF",
+    name=_("Webstuff"),
+    description=_("Provides a collection of resources for the web"),
+    version="1.0",
+    gramps_target_version=MODULE_VERSION,
+    fname="webstuff.py",
+    load_on_reg=True,
+    process="process_list",
+    status=STABLE,
+)
